* this file estimates firm-level revenue-based production functions
set more off
use "rootfile.dta", clear
	drop  pnic2 pnic3 pnic4 pnic2yr

	* attach the main industry code to the firm/ keep sectors as before
	gen nic2 = int(nic4/100)
	replace nic2	=	17 if nic2==18
	replace nic2 	=	31 if nic2==32
	keep if inlist(nic2,15,17,18,21,24,25,26,27,28,29,31,32,34)

	
* creating firm-level tariffs, weighted by product sales
	bysort fid year: egen svtot = 	sum(sv)
	gen p_qt_w		= 	p_qt*(sv/svtot)
	gen p_tf_w		=	p_tf*(sv/svtot)
	bysort fid year: egen pqt_F	=	sum(p_qt_w)
	bysort fid year: egen ptf_F	=	sum(p_tf_w)
		drop p_qt_w p_tf_w

*identify initial main industry of firm
	gsort fid year - sv
	by fid year: g rank = _n
	by fid: egen minyear = min(year)
	g tmp_cl_pnic_initial = cl_pnic if year==minyear & rank==1
	by fid: egen cl_nic_initial = max(tmp_cl_pnic_initial)
		drop tmp_cl_pnic_initial
	
*collapse to firm level
	sort fid year nic2
	drop if fid==fid[_n-1] & year==year[_n-1]

	gen r_u = r+ln(xmfgshare)
	gen lnN=ln(n)

* create data for LP/OP estimation on firm-level R-PFs.
	gen time 	=	year-1988
	gen time2	=	time^2
	gen exp 	= 	s173~=0
	replace exp = 0 if s173==.

	gen lxmfg 	= 	ln(xmfgshare)
	xtset fid year, yearly

* create translog terms:
	gen k2		=	k^2
	gen l2		=	l^2
	gen m2		=	m^2
	gen lk		=	l*k
	gen lm		=	l*m
	gen mk		=	m*k
	gen lmk		=	l*m*k

* Model LP/OP
	gen betaL_cf 	=.
	gen betaM_cf	=.
	gen betaK_cf	=.
	egen nrind=group(nic2)
	egen NrInd=max(nrind)

	global N=NrInd
	global exogCD lnN  k l time time2 L.k L.k2 L.m2 L.mk L.exp L.l2 L.lk  L.lmk 
	global endogCD m lxmfg    
	global instrCD L.m p_qt L.p_qt L.lxmfg

	qui forvalues i=1/$N {
		xi: ivreg2 r_u ${exogCD} i.year (${endogCD}  = ${instrCD}) if nrind==`i', gmm2s 
		gen bl_cf`i'=_b[l]
		gen bm_cf`i'=_b[m]
		gen bk_cf`i'=_b[k]

		replace betaL_cf = bl_cf`i' if `i'==nrind
		replace betaM_cf = bm_cf`i' if `i'==nrind
		replace betaK_cf = bk_cf`i' if `i'==nrind
	}

	preserve
		keep cl_pnic year p_qt p_tf
		duplicates drop
		rename cl_pnic cl_nic_initial
		rename p_qt FIRM_qt
		rename p_tf FIRM_tf
		save tmp_clnictf,replace
	restore
	merge m:1 cl_nic_initial year using tmp_clnictf
		drop if _m==2
		drop _m
		erase  tmp_clnictf.dta

	*get 2-digit initial industry code
	tostring cl_nic_initial, g(cl_nic_initial_string)
	g len = length(cl_nic_initial_string)
	g cl_nic_initial_2digit = .
		replace cl_nic_initial_2digit = cl_nic_initial if len==2
		replace cl_nic_initial_2digit = floor(cl_nic_initial/10) if len==3
		replace cl_nic_initial_2digit = floor(cl_nic_initial/100) if len==4
		drop len cl_nic_initial_string
	label var cl_nic_initial_2digit "2-digit initial industry code of firm"
	gen markup_ft		=	betaM_cf*((totsales*xmfgshare)/(s110*xmfgshare))
	gen lmu_ft		=	ln(markup_ft)
	keep fid year betaL_cf betaM_cf betaK_cf nic2 lmu_ft FIRM_tf FIRM_qt  cl_nic_initial_2digit cl_nic_initial
	lab var betaL_cf "labor elasticity"
	lab var betaM_cf "material elasticity"
	lab var betaK_cf "capital elasticity"
	lab var FIRM_tf "firm-specific tariff"
	lab var FIRM_qt "firm-specific input tariff"
	lab var cl_nic_initial_2digit "initial 2-digit firm industry code"
	lab var cl_nic_initial "initial firm industry code"
save cdfirmrevenue,replace

