**Table 1: Summary Statistics
use estimationfile,clear
	bys year: egen totoutput = sum(sv)
	bys pnic2 year: egen totputput_pnic2 = sum(sv)
	g shv_tot = totputput_pnic2/totoutput
	g spf = n==1
	bys pnic2: egen uniqueproducts = nvals(pcode12)
	collapse (mean) shv_tot uniqueproducts (sum) itag spf, by(pnic2 year)
	collapse (mean) shv_tot itag spf uniqueproducts, by(pnic2)
	count
	local k=r(N)+1
	set obs `k'
	foreach v of varlist shv_tot itag spf unique {
		egen sum_`v' = sum(`v')
		replace `v' = sum_`v' if pnic2==.
		drop sum_`v'
		}
	outsheet using ${tables}/table1.csv,comma replace	
	
*Table 3: Average Output Elasticities, by Sector
use estimationfile,clear
	g rts_theta_l = theta_L_fjt_x
	g rts_theta_m = theta_fjt_x
	g rts_theta_k = theta_K_fjt_x
	g rts         = RTS_tl_x
	
	collapse (mean) nobs1=nrobs1_st l1=rts_theta_l m1=rts_theta_m k1=rts_theta_k rts1=rts (sd) nobs2=nrobs1_st l2=rts_theta_l m2=rts_theta_m k2=rts_theta_k rts2=rts, by(pnic2)
	reshape long nobs l m k rts, i(pnic2) j(t)
	sort pnic2 t
	drop t
	outsheet using ${tables}/table3.csv, comma replace

*Table 4: Median Output Elasticities, by Sector
use estimationfile,clear
	g rts_theta_l = theta_L_fjt_x
	g rts_theta_m = theta_fjt_x
	g rts_theta_k = theta_K_fjt_x
	g rts         = RTS_tl_x
	collapse (p50) rts_* rts, by(pnic2) 
	outsheet using ${tables}/table4.csv, comma replace 
	
*Table 5: Output Elasticities, Input Price Variation and Sample Selection	
use estimationfile,clear
	keep if n==1
	collapse (p50) theta2_L theta2_fjt theta2_K RTS2 theta3_L theta3_fjt theta3_K RTS3, by(pnic2)
	outsheet using ${tables}/table5.csv, comma replace 
	

*Table 6: Markups, by Sector
use estimationfile,clear
	drop if cut3_lmu_x==0
	egen avgmu = mean(mu)
	egen medmu = pctile(mu), p(50)
	collapse (mean) avgmu medmu mean_mu=mu_x (p50) median_mu=mu_x, by(pnic2)
	count
	local k = r(N)+1
	set obs `k'
	sum avgmu
	replace mean_mu = r(mean) if pnic==.
	sum medmu
	replace median_mu = r(mean) if pnic==.
	drop avgmu medmu
	outsheet using ${tables}/table6.csv, comma replace 


*Table 7: Pass-Through of Costs to Prices
use estimationfile,clear
	tsset fup12 year
	xtreg luv lmc_x if cut3_lmu_x & year<=1997, i(fup12) fe cluster(fid)
		est store pass1
	xtivreg2 luv (lmc_x = p_qt l.lmc_x) if cut3_lmu_x & year<=1997, i(fup12) fe cluster(fid) 
		est store pass2
		g sam = e(sample)
	xtivreg2 luv (lmc_x = p_qt l2.lmc_x) if cut3_lmu_x & year<=1997, i(fup12) fe cluster(fid) 
		est store pass4
		g sam1 = e(sample)
	esttab pass* using ${tables}/table7.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(lmc_x) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N singleton widstat, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace

*Table 8: Prices and Output Tariffs, Annual Regressions
use estimationfile,clear
	keep if year<=1997
	global tf = -.61974328
	global qt = -.23949646
	qui tab pnic2yr, g(_pnic2yr)
	qui tab year, g(_yr)
	local yrlist3 = "_yr*"
	local yrlist4 = "_pnic2yr*"
	keep if cut3_lmu_x

	forval y = 3(1)4 {
	foreach v of varlist luv_x {
		xi: xtreg `v' p_tf `yrlist`y'', fe i(fup12) cluster(cl_pnic)
			est store table8_`y'
			lincom ${tf}*p_tf
			g total_m_`y'    = 100*r(estimate)
			g total_sd_`y'   = 100*r(se)
			}
		}
	esttab table8* using ${tables}/table8.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(p_tf) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	keep total*
	duplicates drop
	outsheet using ${tables}/table8_total.csv,comma replace
	est clear

*Table 9: Prices, Costs and Markups and Tariffs
use estimationfile,clear
	keep if year<=1997
	global tf = -.61974328
	global qt = -.23949646
	qui tab pnic2yr, g(_pnic2yr)
	qui tab year, g(_yr)
	keep if cut3_lmu_x

	qui xtreg lmu_x p_tf p_qt _pnic2yr*, fe i(fup12) cluster(cl_pnic)
		g markup_sample = e(sample)
	
	foreach v of varlist luv_x lmc_x lmu_x {
		xi: xtreg `v' p_tf p_qt _pnic2yr* if markup_sample, fe i(fup12) cluster(cl_pnic)
			est store table9_`v'
			lincom ${tf}*p_tf + ${qt}*p_qt
			g total_m_`v'   = 100*r(estimate)
			g total_sd_`v'   = 100*r(se)
			}
	esttab table9* using ${tables}/table9.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(p_tf p_qt)  starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	keep total*
	duplicates drop
	outsheet using ${tables}/table9_total.csv,comma replace

*Table 10: Pro-Competitive Effects of Output Tariffs
est clear
use estimationfile,clear
	keep if year<=1997
	drop if lmu_x==.
	qui tab pnic2yr, g(_pnic2yr)

	*initial markup rank
	bys cl_pnic year: egen tile = xtile(lmu_x), nq(10)
	sort fup12 year
	by fup12: g c = _n
	g tmp = tile if c==1
		by fup12: egen murank = max(tmp)
		g top = murank==10
	
	tsset fup12 year
	forval k = 1/2 {
		g lmc_x_`k' = lmc_x^`k'
		g lag_lmc_`k'   = l.lmc_x_`k'
		}
		drop lmc_x 
	drop if cut3_lmu_x==0

	xtreg lmu_x lmc_x_* p_tf _pnic2yr* , fe i(fup12) cluster(cl_pnic)
		est store table10a
	xi: xtivreg2 lmu_x (lmc_x_1 lmc_x_2 = p_qt lag_lmc_1 lag_lmc_2 ) p_tf _pnic2yr*, fe i(fup12) cluster(cl_pnic) ffirst
		est store table10b
	xi: xtreg lmu_x lmc_x_1 lmc_x_2 i.top*p_tf _pnic2yr*, fe i(fup12)
		est store table10c
	xi: xtivreg2 lmu_x (lmc_x_1 lmc_x_2 = p_qt lag_lmc_1 lag_lmc_2 ) i.top*p_tf _pnic2yr*, fe i(fup12) cluster(cl_pnic) ffirst
		est store table10d
	esttab table10* using ${tables}/table10.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(p_tf _ItopXp_tf_1) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N singleton widstat, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	est clear

*Figure 1: Marginal Costs and Quantities
use estimationfile,clear
	egen fidyr = group(fid year)
	g cons1 = 1
	rename q_j lq 
	qui foreach v of varlist lq lmu_x lmc_x {
		areg `v', a(up12y) 
			predict r_`v',r
			replace r_`v' = . if r_`v' == 0 /*remove zeros */
		areg r_`v', a(fidyr) 
			predict r2_`v',r
			}
	foreach v of varlist r_lq r_lmu_x r_lmc_x r2_lq r2_lmu_x r2_lmc_x {
		foreach i of numlist 3 97 {
			bys pnic2: egen p`i'_`v' = pctile(`v'), p(`i')
			}
		g cut3_`v'  = `v'>p3_`v' & `v'<p97_`v'
		drop p3_`v' p97_`v'
		}
	bys fid year: g N = _N
	twoway (scatter r_lmu_x r_lq if cut3_r_lmu_x & cut3_r_lq, m(x)) (lfit r_lmu_x r_lq if cut3_r_lmu_x & cut3_r_lq, lp(solid) lc(black)  lw(thick)), title("Markups and Quantity") legend(off) xtitle("Log Quantity") ytitle("Log Markups") graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure1a.gph,replace) nodraw
	twoway (scatter r_lmc_x r_lq if cut3_r_lmc_x & cut3_r_lq, m(x)) (lfit r_lmc_x r_lq if cut3_r_lmc_x & cut3_r_lq, lp(solid) lc(black)  lw(thick)), title("Marginal Costs and Quantity") legend(off) xtitle("Log Quantity") ytitle("Log Marginal Costs") graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure1b.gph,replace) nodraw
	graph combine ${tables}/figure1a.gph ${tables}/figure1b.gph, caption("Variables demeaned by product-year FEs." "Markups, cost and quantity outliers are trimmed below and above 3rd and 97th percentiles.",span size(vsmall)) graphregion(lcolor(white) fcolor(white)) saving("${tables}/figure1.gph",replace) nodraw
	graph use "${tables}/figure1.gph"
	graph export "${tables}/figure1.eps",replace as(eps)
	foreach i in figure1a figure1b figure1 {
		erase ${tables}/`i'.gph
		}

	twoway (scatter r2_lmu_x svshare if cut3_r2_lmu_x & N~=1, m(x)) (lfit r2_lmu_x svshare if cut3_r2_lmu_x & N~=1, lp(solid) lc(black)  lw(thick)), title("Markups vs Sales Share")        subtitle("Multiple-Product Firms") legend(off) xtitle("Within-Firm Product Sales Share") ytitle("Log Markups, demeaned") graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure2a.gph,replace) nodraw
	twoway (scatter r2_lmc_x svshare if cut3_r2_lmc_x & N~=1, m(x)) (lfit r2_lmc_x svshare if cut3_r2_lmc_x & N~=1, lp(solid) lc(black)  lw(thick)), title("Marginal Costs vs Sales Share") subtitle("Multiple-Product Firms") legend(off) xtitle("Within-Firm Sales Share") ytitle("Log Marginal Costs, demeaned") graphregion(lcolor(white) fcolor(white))saving(${tables}/figure2b.gph,replace) nodraw
	graph combine ${tables}/figure2a.gph ${tables}/figure2b.gph, caption("Markups and marginal costs are demeaned by product-year and firm-year FEs." "Markup and marginal cost outliers are trimmed below and above 3rd and 97th percentiles.",span size(vsmall)) graphregion(lcolor(white) fcolor(white)) saving("${tables}/figure2.gph",replace) nodraw
	graph use "${tables}/figure2.gph"
	graph export "${tables}/figure2.eps",replace as(eps)
	foreach i in figure2a figure2b figure2 {
		erase ${tables}/`i'.gph
		}

*Figures 3/4: Distribution of Prices, Costs and Markups in 1989 and 1997	
use estimationfile,clear
	keep year fup12 lmu_x lmc_x luv_x pnic*
	keep if year==1989|year==1997
	tsset fup12 year
	bys fup12: g c = _N
	keep if c == 2
		drop c

	drop if luv_x==.|lmc_x==.|lmu_x==.
	qui foreach v of varlist luv_x lmc_x lmu_x {
		xi: areg `v', a(fup12)
			predict r_`v',r
		foreach j of numlist 3 97 {
			egen p`j'_r_`v' = pctile(r_`v'), p(`j')
			}
			g cut3_r_`v'  = r_`v'>=p3_r_`v' & r_`v'<=p97_r_`v'
			drop p*_r_`v'
		}
	egen cut3=rmin(cut3_r_*)
	keep if cut3
	keep fup12 year r_lmu_x r_lmc_x r_luv_x
	reshape wide r_lmu_x r_lmc_x r_luv_x, i(fup12) j(year)

	foreach y in 1989 1997 {
		foreach v in r_lmu_x r_lmc_x r_luv_x {
			kdensity `v'`y', generate(X`v'`y' D`v'`y') nodraw
			}
		}
	twoway (line Dr_luv_x1989 Xr_luv_x1989, lp(dash) lc(gs5)  lw(thick)) (line Dr_luv_x1997 Xr_luv_x1997, lp(solid) lc(black)  lw(thick)), xlabel(-.6(.3).6)  title("Distribution of Prices") ytitle("Density") xtitle("Log Prices") legend(rows(1) order(1 "1989" 2 "1997")) caption("Sample only includes firm-product pairs present in 1989 and 1997." "Outliers above and below the 3rd and 97th percentiles are trimmed.",size(vsmall) span) graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure3.gph,replace)  nodraw
	twoway (line Dr_lmc_x1989 Xr_lmc_x1989, lp(dash) lc(gs5)  lw(thick)) (line Dr_lmc_x1997 Xr_lmc_x1997, lp(solid) lc(black)  lw(thick)), xlabel(-1.5(.5)1.5) title("Distribution of Marginal Costs") ytitle("Density") xtitle("Log Marginal Costs") legend(rows(1) order(1 "1989" 2 "1997")) caption("Sample only includes firm-product pairs present in 1989 and 1997." "Outliers above and below the 3rd and 97th percentiles are trimmed.",size(vsmall) span) graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure4a.gph,replace) nodraw
	twoway (line Dr_lmu_x1989 Xr_lmu_x1989, lp(dash) lc(gs5)  lw(thick)) (line Dr_lmu_x1997 Xr_lmu_x1997, lp(solid) lc(black)  lw(thick)), xlabel(-1.5(.5)1.5) title("Distribution of Markups") ytitle("Density") xtitle("Log Markups") legend(rows(1) order(1 "1989" 2 "1997")) caption("Sample only includes firm-product pairs present in 1989 and 1997." "Outliers above and below the 3rd and 97th percentiles are trimmed.",size(vsmall) span) graphregion(lcolor(white) fcolor(white)) saving(${tables}/figure4b.gph,replace) nodraw
	foreach i in figure3 figure4a figure4b {
		graph use ${tables}/`i'.gph
		graph export "${tables}/`i'.eps",replace as(eps)
		erase ${tables}/`i'.gph
		}


*Table A1: Controlling for Delicensing
est clear
use estimationfile,clear
	keep if year<=1997
	qui tab pnic2yr, g(_pnic2yr)
	qui xtreg lmu_x p_tf p_qt _pnic2yr* if cut3_lmu_x, fe i(fup12) cluster(cl_pnic)
	g markup_sample = e(sample)
	keep if markup_sample
	qui foreach v of varlist luv_x lmc_x lmu_x {
		xi: xtreg `v' p_tf p_qt p_delicense _pnic2yr*, fe i(fup12) cluster(cl_pnic)
			est store tableA1_`v'
	}
	esttab tableA1* using ${tables}/tableA1.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) drop(*cons* *pnic*) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	est clear

*Table A2: Prices, Markups and Costs and Effective Rate of Protection
est clear
use estimationfile,clear
	keep if year<=1997
	qui tab pnic2yr, g(_pnic2yr)

	qui xtreg lmu_x p_erp _pnic2yr* if cut3_lmu_x, fe i(fup12) cluster(cl_pnic)
	g markup_sample = e(sample)
	keep if markup_sample

	qui foreach v of varlist luv_x lmc_x lmu_x {
		xtreg `v' p_erp _pnic2yr*, fe i(fup12) cluster(cl_pnic)
			est store tableA2_`v'
			}
	esttab tableA2* using ${tables}/tableA2.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(p_erp) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace

*Table A3: Output Elasticities using Firm-Level Revenue Data and Cobb-Douglas Production Function
use cdfirmrevenue,clear
	keep betaL_cf betaM_cf betaK_cf nic2
	duplicates drop
	sort nic2
	outsheet using ${tables}/tableA3.csv,replace comma

*Table A4: Firm-level Markups on Output and Input Tariffs
use cdfirmrevenue,clear
	qui xi: xtreg lmu_ft FIRM_tf FIRM_qt i.year*i.cl_nic_initial_2digit if year<=1997, i(fid) fe cluster(cl_nic_initial)
	estimates store mu_firm
	esttab  mu_firm using ${tables}/tableA4.csv, cells(b(star fmt(%9.6f)) se(fmt(%9.6f))) keep(FIRM_qt FIRM_tf) starlevel(* .1 ** .05 *** .01) stardetach stats(r2 N, fmt(%9.3g)) style(tab) varwidth(8) modelwidth(8) plain replace
	
*Figure A1: Distribution of Markups and Marginal Costs in 1989 and 1997
use estimationfile,clear
	g rts_theta_l = theta_L_fjt_x
	g rts_theta_m = theta_fjt_x
	g rts_theta_k = theta_K_fjt_x
	g rts         = RTS_tl_x
	keep pnic2 rts_* rts
	collapse (median) rts_* rts, by(pnic2)
	save tmp_productionfunctionestimates,replace
use cdfirmrevenue,clear
	keep betaL_cf betaM_cf betaK_cf nic2
	duplicates drop
	*rename industry code to pnic2 to match baseline production function estimates
	rename nic2 pnic2
	merge 1:1 pnic2 using tmp_productionfunctionestimates
	g rts_cf = betaL_cf+betaM_cf+betaK_cf
	twoway (scatter betaL_cf rts_theta_l, ms(x)) (lfit betaL_cf rts_theta_l), xtitle("Our Approach") ytitle("Standard Approach") subtitle("Labor Elasticity") graphregion(lcolor(white) fcolor(white)) legend(off) saving(${tables}/figureA1a,replace) nodraw
	twoway (scatter betaM_cf rts_theta_m, ms(x)) (lfit betaM_cf rts_theta_m), xtitle("Our Approach") ytitle("Standard Approach") subtitle("Material Elasticity") graphregion(lcolor(white) fcolor(white)) legend(off)saving(${tables}/figureA1b,replace) nodraw
	twoway (scatter betaK_cf rts_theta_k, ms(x)) (lfit betaK_cf rts_theta_k), xtitle("Our Approach") ytitle("Standard Approach") subtitle("Capital Elasticity") graphregion(lcolor(white) fcolor(white)) legend(off)saving(${tables}/figureA1c,replace) nodraw
	twoway (scatter rts_cf rts, ms(x)) (lfit rts_cf rts), xtitle("Our Approach") ytitle("Standard Approach")  subtitle("Returns to Scale") graphregion(lcolor(white) fcolor(white)) legend(off) saving(${tables}/figureA1d,replace) nodraw
	graph combine ${tables}/figureA1a.gph ${tables}/figureA1b.gph ${tables}/figureA1c.gph ${tables}/figureA1d.gph, caption("Our Approach takes the elasticities reported in Table 4" "Standard Approach uses elasticities from estimating a Cobb-Douglas function on firm-level data",size(vsmall) span) graphregion(lcolor(white) fcolor(white)) saving("${tables}/figureA1.gph",replace) nodraw
	graph use "${tables}/figureA1.gph"
	graph export "${tables}/figureA1.eps", as(eps) replace
	erase ${tables}/figureA1.gph
	foreach i in a b c d {
		erase ${tables}/figureA1`i'.gph 
		}
		erase tmp_productionfunctionestimates.dta

** bootstrap standard errors
	cap use "${work}/0/bs_table7",clear
	cap outsheet using ${tables}/table7_bs.csv,replace comma 

	cap use "${work}/0/bs_table9",clear
	cap outsheet using ${tables}/table9_bs.csv,replace comma 

	cap use "${work}/0/bs_table10",clear
	cap outsheet using ${tables}/table10_bs.csv,replace comma 

